import { getAddressListApi } from "@/api/address"
import { durationTimeOptions, interviewTypeOptions } from "@/dicts/recruitment"
import dayjs from "dayjs"

export default function getFormJson () {
  return {
    abandon: [
      {
        type: "input",
        item: {
          type: "textarea",
          label: "放弃原因",
          prop: "abandonReason",
          placeholder: "请输入放弃原因",
          trim: true,
          maxlength: 100
        },
        field: {
          rules: [{ required: true, message: "请输入放弃原因" }]
        }
      },
      {
        type: "custom",
        item: {
          label: "人才库分类",
          prop: "talentsBankId",
          value: null,
          component: "app-talents-classify-select"
        },
        field: {
          rules: [{ required: true, message: "请选择人才库分类" }]
        }
      }
    ],
    waitEntry: [
      {
        type: "select",
        item: {
          label: "入职公司",
          prop: "taxSubId",
          placeholder: "请选择入职公司",
          field: "name as label,id as value"
        },
        field: {
          rules: [{ required: true, message: "请选择入职公司" }]
        }
      }
    ],
    arrangeInterview: [
      {
        type: "select",
        item: {
          label: "面试官",
          prop: "interviewerId",
          placeholder: "请选择面试官",
          field: "name as label,id as value"
        },
        field: {
          rules: [{ required: true, message: "请选择面试官" }]
        }
      },
      {
        type: "dateTime",
        item: {
          label: "面试时间",
          prop: "interviewTime",
          // TODO ： 这个不好使
          placeholder: "请选择面试时间",
          type: "datetime",
          valueFormat: "timestamp",
          maxSelectNum: 1,
          format:"yyyy-MM-dd HH:mm",
          defaultValue:dayjs(dayjs().format("YYYY-MM-DD 9:00")).valueOf(),
        },
        field: {
          rules: [{ required: true, message: "请选择面试时间" }]
        }
      },
      {
        type: "select",
        item: {
          label: "面试时长(分钟)",
          prop: "durationTime",
          placeholder: "请选择面试时长",
          options:durationTimeOptions
        },
        field: {
          rules: [{ required: true, message: "请选择面试时长" }]
        }
      },
      {
        type: "select",
        item: {
          label: "面试方式",
          prop: "interviewType",
          placeholder: "请选择面试方式",
          options:interviewTypeOptions,
          onInput:async (value) => {
            const jsonForm = this.$refs["arrangeInterview"]
            const attendScene = value === "3"
            // const videoScene = value === "2"

            // 只有现场面试 ， 才展示面试地址选项
            jsonForm.setIfShow({
              field:{
                addressId:attendScene,
                fullAddress:attendScene
              }
            })
            // 只有视频面试 ， 才展示视频地址
            jsonForm.setIfShow({
              field:{
                // TODO：等待文琦提供接口入参
                // address111111:videoScene
              }
            })

            const parameters = {
              filters: {},
              limit: 2_147_483_647,
              start: 1,
              withDeleted: false,
              withDisabled: false,
              withTotal: true,
            }

            const { list } = await getAddressListApi(parameters)
            jsonForm.setOptions({
              addressId: list.map(item => {
                item.name = `${item.name}（${item.fullAddress}）`
                return item
              })
            })

            jsonForm.setFormValue({
              addressId:"",
              fullAddress:""
            })
            
          },
        },
        field: {
          rules: [{ required: true, message: "请选择面试方式" }]
        }
      },
      {
        type: "select",
        item: {
          label: "面试地址",
          prop: "addressId",
          placeholder: "请选择面试地址",
          ifShow:false,
          field: "name as label,id as value",
          onInput:(value) => {
            const jsonForm = this.$refs["arrangeInterview"]
            const item = jsonForm.getOptionsItem("addressId", value)
            jsonForm.setFormValue({
              fullAddress: item?.fullAddress
            })
          }
        },
        field: {
          rules: [{ required: true, message: "请选择面试地址" }]
        }
      },
      {
        type: "input",
        item: {
          prop: "fullAddress",
          label: "详细地址",
          ifShow:false,
          disabled:true,
          placeholder: "选择面试地址后，该内容自动带出",
        },
      },
      {
        type: "member",
        item: {
          label: "面试联系人",
          prop: "contactId",
          placeholder: "请选择面试联系人",
          maxSelectNum: 1,
          onChange:(data) => {
            if (!data.length) return 
            const [userData] = data
            const phone = userData.data.cellPhone
            const jsonForm = this.$refs["arrangeInterview"]
            jsonForm.setFormValue({
              contactMobile:phone
            })
          }
        },
        field: {
          rules: [{ required: true, message: "请选择面试联系人" }]
        }
      },
  
      {
        type: "input",
        item: {
          label: "面试联系人电话",
          prop: "contactMobile",
          placeholder: "请输入面试联系人电话",
          trim: true,
          maxlength: 11
        },
        field: {
          rules: [{ required: true, message: "请输入面试联系人电话" }, { type: "cellphone", message: "请输入正确的手机号" },]
        }
      },
  
      {
        type: "input",
        item: {
          label: "视频地址",
          prop: "address111111",
          placeholder: "请输入视频地址",
          trim: true,
          maxlength: 100,
          ifShow:false
        },
        field: {
          rules: [{ required: true, message: "请输入视频地址" }]
        }
      },
  
      {
        type: "input",
        item: {
          type: "textarea",
          label: "备注",
          prop: "remark",
          placeholder: "请输入需要提示候选人的信息",
          maxlength: 100,
          trim: true
        },
        field: {
          rules: [{ required: true, message: "请输入需要提示候选人的信息" }]
        }
      },
    ],
    recommend: [
      {
        type: "select",
        item: {
          label: "简历评估人",
          prop: "interviewerId",
          placeholder: "请选择简历评估人",
          field: "name as label,id as value"
        },
        field: {
          rules: [{ required: true, message: "请选择简历评估人" }]
        }
      },
      // {
      //   type: "input",
      //   item: {
      //     type: "textarea",
      //     label: "备注",
      //     prop: "remark",
      //     maxlength: 200,
      //     trim: true,
      //     placeholder: "输入候选人备注信息(仅hr可见)",
      //   },
      // },
    ],
    assignJob: [
      {
        type: "select",
        item: {
          label: "招聘职位",
          prop: "jobId",
          options: [],
        },
        field: {
          rules: [{ required: true, message: "请选择招聘职位" }]
        }
      }
    ],
    assignTalent: [{
      type: "custom",
      item: {
        label: "人才库分类",
        prop: "talentsBankId",
        value: null,
        component: "app-talents-classify-select"
      },
      field: {
        rules: [{ required: true, message: "请选择人才库分类" }]
      }
    }]
  }
}