import { arrangeInterviewApi, interviewFinishApi, recommendApi } from "@/api/recruitment"
import { abandonCandidateApi, waitEntryCandidateApi } from "@/api/candidate"
import { APP_RESUME_SEND_OFFER_BASIC_INFO } from "@/utils/storage/constant"
import { moveTalentsBankResumeApi } from "@/api/talents-bank-classify"
import { getJobInterviewListApi } from "@/api/job-management"
import { getOptionsListApi } from "@/api/options"
import { getAddressListApi } from "@/api/address"
import { showMessage } from "@/utils/message"
import { assignJobApi } from "@/api/resume"
import cache from "@/utils/storage"

export default {
  computed: {
    candidateActionButton() {
      return this.$refs["app-candidate-action-button"]
    }
  },
  methods: {
    toggleDialog(show = true) {
      this.candidateActionButton.ifShowDialog = show
    },
    _actionButtonClick({ api, row, code, title, size, columns }) {
      this.candidateActionButton.code = code
      this.candidateActionButton.title = title
      this.candidateActionButton.dialogSize = size
      this.candidateActionButton.columns = columns

      this.toggleDialog()
      this.candidateActionButton.callback = async (formData) => {
        await api({
          ...formData,
          resumeId: row.resumeId,
        })
        showMessage("操作成功")
        this.toggleDialog(false)
        this.reload()
      }
    }
  },
  data() {
    return {
      actionButtons: [
        // {
        //   label: "测试",
        //   id: "test",
        //   click: async (row) => {
        //     console.log("测试")
        //     this.dialogVisible = true
        //   }
        // },
        {
          label: "推荐",
          id: "recommend",
          ifShow:(row) => row.operations.includes("recommend"),
          click: async (row) => {

            this._actionButtonClick({
              api:recommendApi, 
              row, 
              code:"recommend", 
              title:"推荐",
              size:"medium"
            })

            const interviewerOptions = await getJobInterviewListApi({
              applyJobId:row.applyJobId
            })

            this.candidateActionButton.$refs["recommend"].setOptions({
              interviewerId:interviewerOptions
            })
           
          }
        },
      
        {
          label: "安排面试",
          id: "arrangeInterview",
          ifShow:(row) => row.operations.includes("arrangeInterview"),
          click:async(row) => {
           
            this._actionButtonClick({
              api:arrangeInterviewApi, 
              row, 
              code:"arrangeInterview", 
              title:"安排面试",
              columns:2
            })

            const [{ list:addressOptions }, interviewerOptions] = await Promise.all([getAddressListApi({
              start:1,
              limit:100_000
            }), getJobInterviewListApi({
              applyJobId:row.applyJobId
            })])

            this.candidateActionButton.$refs["arrangeInterview"].setOptions({
              addressId: addressOptions,
              interviewerId:interviewerOptions
            })

          }
        },
        {
          label: "面试完成",
          id: "completeInterview",
          ifShow:(row) => row.operations.includes("completeInterview"),
          click: (row) => {
            this.$oConfirm({
              title:"面试完成",
              message:"面试完成候选人将进入下一阶段，请确认是否操作",
              confirm:async() => {
                await interviewFinishApi({
                  resumeId:row.resumeId
                })
                this.reload()
                showMessage("操作成功")
              },
            })
          }
        },
        {
          label: "录用申请",
          id: "employApproval",
          ifShow:(row) => row.operations.includes("employApproval"),
          click: (row) => {
            this.$router.push(`/recruitment/${row.resumeId}/approval?app=RECRUIT`)
          }
        },
        {
          label: "发放offer",
          id: "sendOffer",
          ifShow:(row) => row.operations.includes("sendOffer"),
          click: (row) => {
            cache.save(APP_RESUME_SEND_OFFER_BASIC_INFO, row)
            this.$routerPush({
              name:"sendOffer",
              params:{
                resumeId:row.resumeId,
              }
            })
          },
        },
        {
          label: "待入职",
          id: "waitEntry",
          ifShow:(row) => row.operations.includes("waitEntry"),
          click:async(row) => {
           
            this._actionButtonClick({
              api:waitEntryCandidateApi, 
              row, 
              code:"waitEntry", 
              title:"待入职",
              size:"medium"
            })

            const options = await getOptionsListApi({
              optionDataSource:"8"
            })

            this.candidateActionButton.$refs["waitEntry"].setOptions({
              taxSubId:options
            })
          }
        },
        {
          label: "办理入职",
          id: "entry",
          ifShow:(row) => row.operations.includes("entry"),
          click: (row) => {
            const url = `${window.env.toUrl.hr}/staff-manage/entry-manage?key=${row.mobile}&app=HR`
            this.$windowOpen(url)
          }
        },
        {
          label: "放弃",
          id: "abandon",
          ifShow:(row) => row.operations.includes("abandon"),
          click:row => 
            this._actionButtonClick({
              api:abandonCandidateApi, 
              row, 
              code:"abandon", 
              title:"放弃",
              size:"medium"
            })
        },
        {
          label:"分配职位",
          id: "assignJob",
          ifShow:(row) => row.operations.includes("assignJob") || row.applyId === 0 || row.applyId === null,
          click:async(row) => {

            this._actionButtonClick({
              api:assignJobApi, 
              row, 
              code:"assignJob", 
              title:"分配职位",
              size:"medium"
            })

            const options = await getOptionsListApi({
              optionDataSource:"1",
              withDeleted:false,
              withDisabled: false,
            })
            this.candidateActionButton.$refs["assignJob"].setOptions({
              jobId:options
            })

          }
        }, {
          id: "assignTalent",
          label:"人才库分类",
          ifShow:(row) => row.operations.includes("assignTalent"),
          click:(row) => {

            this._actionButtonClick({
              api:moveTalentsBankResumeApi, 
              row, 
              code:"assignTalent", 
              title:"人才库分类",
              size:"medium"
            })

            setTimeout(() => {
              this.candidateActionButton.$refs.assignTalent.setFormValue({
                talentsBankId:row.talentsBankId
              })
            }, 600)
          }
        },
       
        // {
        //   label: "评估合格",
        //   id: "accessPass",
        //   click: (row) => {
        //     this.candidateActionButton.ifShowDialog = true
        //   }
        // },
        // {
        //   label: "评估不合格",
        //   id: "accessNotPass",
        //   click: (row) => {
        //     this.candidateActionButton.ifShowDialog = true
        //   }
        // },
       
        // {
        //   label: "拒绝面试",
        //   id: "refuseInterview",
        //   click: (row) => {
        //     this.candidateActionButton.ifShowDialog = true
        //   }
        // },
       
        // {
        //   label: "面试合格",
        //   id: "interviewPass",
        //   click: (row) => {
        //     this.candidateActionButton.ifShowDialog = true
        //   }
        // },
        // {
        //   label: "录用审批通过",
        //   id: "employApprovalPass",
        //   click: (row) => {
        //     this.candidateActionButton.ifShowDialog = true
        //   }
        // },
        // {
        //   label: "录用审批未通过",
        //   id: "employApprovalRefused",
        //   ifShow: (row) => true,
        //   click: (row) => showMessage("点击离职"),
        // },
        // {
        //   label: "接受offer",
        //   id: "acceptOffer",
        //   click: (row) => showMessage("点击删除"),
        // },
        // {
        //   label: "拒绝offer",
        //   id: "refuseOffer",
        //   click: (row) => showMessage("点击删除"),
        // },
       
      ],
    }
  }
}