// import { getMerchantApi } from "@/api/common"
import { findArrayItem } from "./tree"
import _ from "lodash"
import cache from "./storage"
import { APP_INCREMENT_MAP_INFO } from "./storage/constant"

// 获取URL全部参数 ， 返回一个对象
export function getUrlAllParameters() {
  const url = decodeURI(window.location.href)
  const result = {}
  const url_data = _.split(url, "?").length > 1 ? _.split(url, "?")[1] : null
  if (!url_data) return {}
  const parameters_array = _.split(url_data, "&")
  for (const item of parameters_array) {
    const key = _.split(item, "=")[0]
    const value = _.split(item, "=")[1]
    result[key] = value
  }
  return result
}

export const setFavicon = async () => {
  // try {
  //   await getMerchantApi()
  // } catch (error) {
  //   // 因为用的统一API拦截方法，这里返回的code 跟费控的code 不一致，所以只能在catch 中拦截 获取响应结果
  //   const platFromLogoUrl = error?.data?.platFromLogoUrl
  //   const link = document.createElement("link")
  //   link.setAttribute("rel", "shortcut icon")
  //   link.setAttribute("type", "image/x-icon")
  //   link.href = platFromLogoUrl
  //   document.head.append(link)
  // }
}

/**
* @description: 设置options的数据 根据用户传入的 fields 进行映射
* @param { Array } options
* @param { Object } fields
*/
export const setOptionsFiled = (options, fields) => {
  if (!fields) return new Error("请传入fields字段")
  findArrayItem(options, item => {
    for (const key in item) {
      if (fields[key]) item[fields[key]] = item[key]
    }
  })
}

/**
* @description: 把field字段映射城对象
* @param { String } field
* @return { Record<string,string> }
*/
export const filedToObject = (field) => {
  if (!field) return ""
  const fields = field.split(",")
  const conversionResultKey = {}
  for (const item of fields) {
    const [oldKey, newKey] = item.split("as")
    conversionResultKey[oldKey.trim()] = newKey.trim()
  }
  return conversionResultKey
}

export const getOptionsItem = (options, value) => {
  try {
    const result = options.find(item => String(item.value) === String(value))
    if (result) return result
    console.error("没有找到下拉选项对应的value", { value, options })
    return {}
  } catch (error) {
    console.error(error)
    return {}
  }
}

export const noop = () => {}

export const arrayToMap = (list, key = "id") => {
  const result = {}
  for (const item of list) {
    result[item[key]] = item
  }
  return result
}

/**
 * @description: 手动清空KeepAlive的缓存记录
 * @param { Object } vueInstance 当前组件内的Vue实例
 */
export const removeKeepAliveCacheForVueInstance = vueInstance => {
  const key =
      vueInstance.$vnode.key ??
      vueInstance.$vnode.componentOptions.Ctor.cid + (vueInstance.$vnode.componentOptions.tag ? `::${vueInstance.$vnode.componentOptions.tag}` : "")
  const { cache } = vueInstance.$vnode.parent.componentInstance
  const { keys } = vueInstance.$vnode.parent.componentInstance
  if (cache[key]) {
    vueInstance.$destroy()
    delete cache[key]
    const index = keys.indexOf(key)
    if (index > -1) {
      keys.splice(index, 1)
    }
  }
}

// 是否为标准版本
export const isStandardVersion = (code, level = 1) => {
  const map = cache.get(APP_INCREMENT_MAP_INFO)
  console.log({ code }, map[code])
  return map[code] === level
}