import detailRightInfoUploadProfilePhoto from "@/views/recruitment/components/detail-right-info-profile-photo.vue"
import appTalentsClassifySelect from "@/components/app-talents-classify-select/index.vue"
import upload from "@/components/app-json-form/index-upload.vue"
import { getOptionsListApi } from "@/api/options"
import { VALIDATE_TYPE } from "@/enum/form"
// import { showMessage } from "./message"
import { getOptionsItem } from "."
import _ from "lodash"
import { getEmailListApi } from "@/api/platform-management"
import { getAddressListApi } from "@/api/address"

export const FIELD_TYPE = {
  // 文本
  1:(item) => {
    item.type = "input"
    item.item.trim = true
    item.item.maxlength = item.item.maxLength || 10_000
  },
  // 多行文本
  2:(item) => {
    item.type = "input"
    item.item.trim = true
    item.item.type = "textarea"
    item.item.showWordLimit = true
    item.field.colspan = 2
    item.item.maxlength = item.item.maxLength || 10_000
  },
  // 日期
  3:(item) => {
    item.type = "dateTime"
    item.item.type = "date"
    item.item.valueFormat = "yyyy-MM-dd"
  },
  // 选项
  4:async(item) => {
    item.type = "select"
    const { optionDataSource } = item.item
    if (!optionDataSource) return 

    // 硬编码 公司地址 需要单独调用接口
    if (optionDataSource === 6) {
      const parameters = {
        filters: {},
        limit: 2_147_483_647,
        start: 1,
        withDeleted: false,
        withDisabled: false,
        withTotal: true,
      }
      const { list } = await getAddressListApi(parameters)
      item.item.options = list.map(item => {
        item.label = `${item.name}(${item.fullAddress})`
        item.value = item.id
        return item
      })
      return 
    }
    
    const options = await getOptionsListApi({
      optionDataSource,
    })
    item.item.options = options
  },
  // 数值
  5:(item) => {
    item.type = "input"
    item.item.maxlength = 8
  },
  // 图片
  6:(item) => {
    item.type = "custom"
    item.item.component = detailRightInfoUploadProfilePhoto
  },
  // 文件
  7:(item) => {
    item.type = "custom"
    item.item.component = upload
    item.field.colspan = 2
  },
  // 关联员工
  8:(item) => {
    item.type = "member"
    item.item.maxSelectNum = 1
  },
  9:(item) => {
    item.type = "dept"
    item.item.maxSelectNum = 1
  },
  // 岗位
  10:async (item) => {
    item.type = "select"
    const options = await getOptionsListApi({
      optionDataSource:1,
      optionGroupCode:item.groupCode,
    })
    item.item.options = options

  },
}

const setDefinitionFieldRules = (item) => {
  item.field.rules = []
  if (item.item.required) {
    item.field.rules.push({
      required: true, message: `请输入${item.item.label}` 
    })
  }

  if (item.item.validateType) {
    const rule = VALIDATE_TYPE[item.item.validateType]
    item.field.rules.push({
      type:rule.type, message: rule.message
    })
    item.item.validateTrigger = "blur"
  }

  if (item.originalType === 5) {
    item.field.rules.push({
      validator(value) {
        const { decimalDigits, label } = item.item
        if (!value) return null

        const reg = {
          0:/^\d+$/,
          1:/^\d+(\.\d)?$/,
          2:/^\d+(\.\d{0,2})?$/,
        }
        
        if (reg[decimalDigits].test(value)) return null 
        return `${label}格式有误`
      },
    })
  }
}

export const formDefinition2FormJson = (groups) => {
  // 过滤没有开启的分组 
  let formJson = _.cloneDeep(groups).filter(item => item.enabled)

  // eslint-disable-next-line no-async-promise-executor
  return new Promise(async (resolve) => {
    for (const groupItem of formJson) {

      for (const item of groupItem.children = groupItem.fields.filter(item => item.enabled)) {
        const formItem = { ...item }
        const { type, fieldName, fieldCode } = formItem

        // 删除type
        delete formItem.type
        // 重新设置 label prop 适配组件
        // formItem.label = `${fieldName}-${type}`
        formItem.label = `${fieldName}`
        formItem.prop = fieldCode

        const newItem = {
          item:formItem,
          type:"input",
          originalType:type,
          field:{},
        }

        // 不同类型type 做不同处理
        try {
          await FIELD_TYPE[type](newItem)
        } catch {
          newItem.type = "input"
        }
        
        // 测试代码
        // item.item.oType = item.type
        // item.item.originalType = item.originalType
        
        // 设置rule规则
        setDefinitionFieldRules(newItem)
        Object.assign(item, newItem)
      }
    }
  
    // 如果分组下面字段 全部隐藏，分组无需展示
    formJson = formJson.filter(item => item.children.length)
    resolve(formJson)
  })
  
}

/**
 * @description: 设置选项的默认值，用于回显
 * @param { Object } formItems 表单选项数据
 * @param { Object } valueData 回显数据对象
 * @param { number } index 分组索引
 */
const setFormItemValue = (formItems, valueData, index = 1) => {
  for (const item of formItems) {

    const { fieldCode, prop, groupCode, options } = item.item

    if (!valueData || !valueData[fieldCode]) {
      item.item.prop = `${prop}_${groupCode}_${index}`
      // 如果没有 默认值数据，无需进行赋值
      item.item.value = ""
    } else {

      item.item.prop = `${prop}_${groupCode}_${index}`
      const value = valueData[fieldCode]
      const valueText = options.length ? getOptionsItem(options, String(value)).label : value
      item.item.valueText = valueText
      item.item.value = `${value}`
    }

    // 用于候选人详情页面编辑
    if (valueData && valueData.id) {
      item.recordId = valueData.id
    }
    
    // eslint-disable-next-line unicorn/consistent-destructuring
    // item.item.label += item.item.prop

  }
}

function setGroupTitleAndAddButton(newItem, options, index = 0) {
  // 是否允许填写多份
  if (newItem.multiple && options && options.onAddGroup) {
    const isRepeatGroup = Number(newItem.children[0].item.prop.slice(-1)) > 1
    newItem.groupNameRender = (h) => {
      const lineVNode = h("div", {
        style:{
          width:"100%",
          borderTop:"1px solid #eee",
          position:" absolute",
        }
      })
      const titleVNode = h("span", {
        style:{
          flex:1
        },
        class:"custom-title-line"
      }, newItem.groupName)
      const deleteButtonVNode =  h("app-text-button", {
        props:{
          type:"delete"
        },
        style:{
          paddingTop:"60px",
        },
        on:{
          click() {
            options.onDeleteGroupRecord(newItem, index)
          }
        }
      }, "删除")
      const addButtonVNode = h("app-text-button", {
        props:{
          type:"add"
        },
        style:{
          top:"-8px",
          position:"relative"
        },
        on:{
          click() {
            options.onAddGroup(newItem)
          }
        },
      }, "添加")
      const childrenVNode = isRepeatGroup ? [ deleteButtonVNode, lineVNode] : [titleVNode, addButtonVNode]
      return h("div", {
        style:{
          position: "relative",
          width:"100%",
          display: "flex",
          alignItems: "center",
          justifyContent:isRepeatGroup ? "flex-end" : "flex-start"
        },
      }, childrenVNode)
    }
  }
}

/**
 * @description: 把后台返回的表单回显数据 跟表单定义数据 进行组合 ， 生成新的formJson
 * @param { Array } definitionFormJson 表单定义的数据
 * @param { Object } formDataValue 表单回显的formValue
 * @return { Array } formJson 新的formJson 数据
 */
export const formValue2FormJson = (definitionFormJson, formDataValue, options) => {
  const newFormJson = []
  // 循环表单定义的数据
  for (const item of definitionFormJson) {
    const newItem = _.cloneDeep(item)
   
    // 根据表单定义的groupCode 获取对应回显的数据
    const valueData = formDataValue[item.groupCode]

    // 如果有对应的回显数据 ， 并且回显数据 有多个分组
    if (valueData && valueData.length > 1) {

      // 循环分组
      for (const [index, value] of valueData.entries()) {
        
        const newIndex = index + 1
        const nextNewItem = _.cloneDeep(newItem)

        nextNewItem.groupCode += newIndex

        newFormJson.push(nextNewItem)
        
        setFormItemValue(nextNewItem.children, value, newIndex)
        setGroupTitleAndAddButton(nextNewItem, options, index)

      }
    } else {
      setGroupTitleAndAddButton(newItem, options)
      // 插入新的FormJson数组中
      newFormJson.push(newItem)
      // 设置插入数据的默认值
      setFormItemValue(newItem.children, valueData && valueData[0])
    }

  }
  return newFormJson
}

// 候选人投递信息模板
function getRecruitmentDeliveryInfoFormObject() {
  return   {
    groupName:"投递信息",
    groupId:"-",
    children:[
      {
        type:"select",
        item:{
          label:"招聘渠道",
          field:"name as label,id as value",
          prop:"sourceChannel_custom_1",
        },
        field:{
          rules: [{ required: true, message: "请选择招聘渠道" }]
        }
      },
      {
        type:"select",  
        item:{
          label:"招聘职位",
          prop:"jobId_custom_1",
          options:[]
        },
        field:{
          rules: [{ required: true, message: "请选择招聘职位" }]
        }
      }, 
      // {
      //   type:"select",
      //   item:{
      //     label:"候选人状态",
      //     prop:"x3",
      //   }
      // }, 
      {
        type:"custom",
        item:{
          label:"人才库分类",
          prop:"talentsBankId_custom_1",
          value:null,
          component:appTalentsClassifySelect
        },
        field:{
          rules: [{ required: true, message: "请选择人才库分类" }]
        }
      }]
  }
}

// 返回投递信息 formJsonItem
export const getRecruitmentDeliveryInfoFormJson = async (formDataValue) => {
  const parameters = {
    "filters":{}, "limit":99_999, "start":1, "withDisabled":false, "withDeleted":false, "withTotal":true
  }
  
  // 获取职位下拉 和 招聘渠道下拉 选项
  const [ jobs, { list:channels } ] = await Promise.all([getOptionsListApi({
    optionDataSource:"1",
    withDeleted: false,
    withDisabled: false
  }), getEmailListApi(parameters)])

  const json = getRecruitmentDeliveryInfoFormObject()

  const getItem = property => json.children.find(item => item.item.prop === `${property}_custom_1`)
  const channel = getItem("sourceChannel").item
  const job = getItem("jobId").item
  const talentsBank =  getItem("talentsBankId").item

  job.options = jobs
  channel.options = channels

  // 默认值设置
  if (formDataValue && formDataValue.custom) {
    const { jobId, talentsBankId, sourceChannel } = formDataValue.custom[0]
    job.value = jobId
    talentsBank.value = talentsBankId
    channel.value = sourceChannel
  }
  
  return json
}

export const definitionFormValue2FormData = (formData) => {
  const newFormData = {}
  // eslint-disable-next-line guard-for-in
  for (const key of Object.keys(formData)) {
    const value = formData[key]
    const [field, groupCode, index] = key.split("_")
    newFormData[groupCode] = !newFormData[groupCode] ? [] : newFormData[groupCode]
    newFormData[groupCode][index - 1] = !newFormData[groupCode][index - 1] ? {} : newFormData[groupCode][index - 1]
    newFormData[groupCode][index - 1][field] = value
  }

  return newFormData
}