import * as constData from "@/dicts/job-management"
import addJobCategory from "./components/add-job-category.vue"
import { isAmount, isPositiveInteger } from "@/utils/rules"

// 0104 qx 最新给的 学历数据
const educationRequiredOptions = [
  {
    label:"不限",
    value:"1"
  },
  {
    label:"小学",
    value:"2"
  },
  {
    label:"初中",
    value:"3"
  },
  {
    label:"中专",
    value:"4"
  },
  {
    label:"高中",
    value:"5"
  },
  {
    label:"大专",
    value:"6"
  },
  {
    label:"本科",
    value:"7"
  },{
    label:"硕士",
    value:"8"
  },{
    label:"博士",
    value:"9"
  },{
    label:"其他",
    value:"10"
  }
]

export default function () {
  return  [
    {
      groupName: "基本信息",
      groupId: 0,
      children: [
        {
          type: "input",
          item: {
            prop: "name",
            label: "职位名称",
            placeholder: "请输入职位名称",
            maxlength: 50,
            trim:true
          },
          field: {
            rules: [{ required: true, message: "请输入职位名称" }],
          },
        },
        {
          type: "select",
          item: {
            prop: "positionId",
            label: "关联岗位",
            placeholder: "请选择岗位",
            options: [],
            field:"name as label,id as value",
          },
        },
        {
          type: "dept",
          item: {
            prop: "deptId",
            label: "用人部门",
            placeholder: "请选择用人部门",
            maxSelectNum: 1
          },
          field: {
            rules: [{ required: true, message: "请选择用人部门" }],
          },
        },
        {
          type: "custom",
          item: {
            prop: "jobCategoryId",
            label: "职位类型",
            component: addJobCategory,
          },
          field: {
            rules: [
              { required: true, message: "请选择职位类型" },
              {
                validator(value) {
                  if (!value.length) return "请选择职位类型"
                  return null
                }
              }
            ],
          },
        },
        {
          type: "select",
          item: {
            prop: "workType",
            label: "用工性质",
            placeholder: "请选择用工性质",
            options: constData.workTypeOptions,
          },
          field: {
            rules: [{ required: true, message: "请选择用工性质" }],
          },
        },
        {
          type: "input",
          item: {
            prop: "employNum",
            label: "招聘人数",
            maxlength:8,
            trim:true,
            placeholder: "请输入招聘人数"
          },
          field: {
            rules: [
              { required: true, message: "请输入招聘人数" },
              { type: "int", message: "请输入整数" },
              { type: "number", max:10_000,  message: "招聘人数不得超出10000" },
              {
                validator(value) {
                  if (isPositiveInteger(value)) return null
                  return "请输入正整数"
                }
              }
            ],
          },
        },
        {
          type: "select",
          item: {
            prop: "addressId",
            label: "工作地址",
            placeholder: "请选择工作地址",
            options: [],
            field:"name as label,id as value",
            onInput:(value) => {
              const jsonForm = this.$refs["json-form"]
              const item = jsonForm.getOptionsItem("addressId", value)
              this.$refs["json-form"].setFormValue({
                fullAddress: item?.fullAddress
              })
            }
          },
          field: {
            hint: "question",
            hintMessage: "若无所需工作地址，可通过（招聘设置>地址管理）添加",
          },
        },
        {
          type: "input",
          item: {
            prop: "fullAddress",
            label: "详细地址",
            trim:true,
            maxlength:100,
            placeholder: "选择工作地址后，该内容自动带出",
          },
        },
      ],
    },
    {
      groupName: "招聘要求",
      groupId: 1,
      children: [
        {
          type: "select",
          item: {
            prop: "experienceRequired",
            label: "工作经验",
            placeholder: "请选择工作经验",
            options: constData.workExperienceOptions,
          },
          field: {
            rules: [{ required: true, message: "请选择工作经验" }],
          },
        },
        {
          type: "select",
          item: {
            prop: "educationRequired",
            label: "学历",
            placeholder: "请选择学历要求",
            options: educationRequiredOptions,
          },
          field: {
            rules: [{ required: true, message: "请选择学历要求" }],
          },
        },
        {
          type: "select",
          item: {
            prop: "languageRequired",
            label: "语种",
            placeholder: "请选择语种要求",
            options: constData.languageOptions,
          },
        },
        {
          type: "radio",
          item: {
            prop: "genderRequired",
            label: "性别",
            multiple: true,
            placeholder: "请选择性别要求",
            value:3,
            options: constData.genderOptions,
          },
        },
        {
          type: "inputRange",
          item: {
            prop: "ageRange",
            label: "年龄",
            multiple: true,
            placeholder: "请输入",
            trim:true,
            maxlength:8,
            options: [
              {
                label: "岁",
                value: 0,
              },
            ],
            checkBoxLabel:"不限"
          },
          field: {
            rules: [
              {
                validator(value) {
                  const [min, max] = value || []
                  if (!min && !max) return null
                  if (!isPositiveInteger(min) || !isPositiveInteger(max)) return "请输入正整数"
                  if (min && !max) return "请输入最大年龄"
                  if (!min && max) return "请输入最小年龄"
                  if (Number(min) > Number(max)) return "最大年龄小于最小年龄"
                  return null
                }
              },
            ],
          },
        },
        {
          type: "inputRange",
          item: {
            prop: "salaryRange",
            label: "薪资范围",
            multiple: true,
            placeholder: "请输入",
            options: constData.salaryPeriodOptions,
            trim:true,
            maxlength:8,
            checkBoxLabel:"面议"
          },
          field: {
            rules: [
              { required: true, message: "请输入薪资范围" },
              {
                validator(value) {
                  const [min, max] = value || []
                  if (!isAmount(min) || !isAmount(max)) return "格式不正确"
                  if (Number(min) > Number(max)) return "最大薪资小于最小薪资"
                  if (Number(min) === 0 || Number(max) === 0) return "格式不正确"
                  return null
                }
              },
            ],
          },
        },
        {
          type: "input",
          item: {
            type: "textarea",
            label: "职位描述",
            prop: "description",
            showWordLimit: true,
            rows:6,
            trim:true,
            maxlength: 3000,
            placeholder: "请输入职位描述（3000字以内）",
          },
          field: {
            colspan: 2,
            rules: [{ required: true, message: "请输入职位描述" }],
          },
        },
      ],
    },
    {
      groupName: "负责人设置",
      groupId: 2,
      children: [
        {
          type: "member",
          item: {
            prop: "recruitManagerIds",
            label: "招聘负责人",
            popupTitle: "招聘负责人",
            placeholder: "请选择招聘负责人",
          },
          field: {
            rules: [{ required: true, message: "请选择招聘负责人" }],
          },
        },
        {
          type: "member",
          item: {
            prop: "interviewManagerIds",
            label: "面试负责人",
            popupTitle: "面试负责人",
            placeholder: "请选择面试负责人",
          },
          field: {
            rules: [{ required: true, message: "请选择面试负责人" }],
          },
        },
      ],
    },
    {
      groupName: "模板设置",
      groupId: 3,
      children: [
        {
          type: "select",
          item: {
            prop: "inviteTemplateId",
            label: "面试邀请模板",
            placeholder: "请选择面试邀请模板",
            options: [],
            field:"name as label,id as value",
          },
          field: {
            rules: [{ required: true, message: "请选择面试邀请模板" }],
          },
        },
        {
          type: "select",
          item: {
            prop: "offerTemplateId",
            label: "offer模板",
            placeholder: "请选择offer模板",
            options: [],
            field:"name as label,id as value",
          },
          field: {
            rules: [{ required: true, message: "请选择offer模板" }],
          },
        },
      ],
    },
  ]

}