import { getEmailListApi } from "@/api/platform-management"
import { educationRecordOptions, genderOptions } from "@/dicts/recruitment"

export const initTopSelectOptions = async (topSelect, field = "sourceChannel") => {
  const parameters = {
    "filters":{}, "limit":99_999, "start":1, "withDisabled":false, "withDeleted":false, "withTotal":true
  }
  const { list } = await getEmailListApi(parameters)
  topSelect.setOptions({
    [field]:list
  })
}

export default function (type) {
  const isTalent = type === "talent"
  return [
    {
      type: "input",
      formItem: {
        prop: "keyword",
        label: isTalent ? "姓名" : "候选人姓名",
        placeholder: isTalent ? "请输入姓名/手机号查询" : "请输入候选人姓名/职位名称查询",
        maxlength:100
      },
    },
    {
      type: "input",
      formItem: {
        prop: "email",
        label: "邮箱",
        trim:true,
        placeholder:"请输入邮箱",
        ifShow:isTalent
      },
    },
    {
      type: "input",
      formItem: {
        prop: "age",
        label: "年龄",
        placeholder: "请输入年龄",
        ifShow:isTalent,
        maxlength:8,
        valueType:"int"
      },
    },
    {
      type: "select",
      formItem: {
        prop: "gender",
        label: "性别",
        placeholder: "请选择性别",
        options:genderOptions,
      },
    },
    {
      type: "input",
      formItem: {
        prop: "workAge",
        label: "工作经验",
        placeholder: "请输入工作经验",
        maxlength:8,
        valueType:"int"
      },
    },
    {
      type: "select",
      formItem: {
        prop: "eduction",
        label: "最高学历",
        placeholder: "请选择最高学历",
        options:educationRecordOptions
      },
    },
    {
      type: "select",
      formItem: {
        prop: "sourceChannel",
        label: "招聘渠道",
        field:"name as label,id as value",
        placeholder: "请选择招聘渠道",
        ifShow:!isTalent,
      },
    },
    {
      type: "member",
      formItem: {
        prop: "recruitManagerId",
        label: "招聘负责人",
        maxSelectNum:1,
        ifShow:!isTalent,
        popupTitle:"招聘负责人",
        placeholder: "请选择招聘负责人",
      },
    },
    // {
    //   type: "member",
    //   formItem: {
    //     prop: "interviewId",
    //     label: "面试负责人",
    //     maxSelectNum:1,
    //     placeholder: "请选择面试负责人",
    //   },
    // },
    {
      type: "member",
      formItem: {
        prop: "creatorId",
        label: "简历添加人",
        maxSelectNum:1,
        ifShow:isTalent,
        placeholder: "请选择简历添加人",
      },
    },
    {
      type: "datePicker",
      formItem: {
        prop: "createTime",
        label: "简历添加时间",
        placeholder: "请选择简历添加时间",
        type: "daterange",
        rangeSeparator: "-",
        startField: "createTimeBegin",
        endField: "createTimeEnd",
        startPlaceholder: "开始日期",
        endPlaceholder: "结束日期",
        format: "yyyy-MM-dd",
        valueFormat: "timestamp",
        ifShow:isTalent,
      },
    },
  ]
}