import repeatResumePopup from "./components/repeat-resume-popup.vue"
import candidateInterviewPopup from "./components/candidate-interview-popup.vue"
import resumeTagPopup from "./components/resume-tag-popup.vue"

export function setCandidateListTableHeader (tableHeader, callback) {
  for (const item of tableHeader) {
    callback && callback(item)

    if (item.prop === "applyJobName") {
      item.minWidth = 150
    }

    if (item.prop === "name") {
      item.minWidth = 120
    }

    if (item.prop === "remark") {
      item.minWidth = 200
    }

    if (item.prop === "recruitManagers") {
      item.minWidth = 120
    }

    if (item.type === "LIST_TEXT") {
      if (!item.minWidth) item.width = 120
      item.formatter = (row) => (row[item.prop] || []).join(",")
    }

    if (item.prop === "tags") {
      item.width = 120
      item.showOverflowTooltip = false
      item.render = (h, row) => {
        if (row.tags === null) return h("span", "-")
        return h("div", {
          style:{
            display:"flex",
            alignItems:"center"
          },
          class:"o-app"
        },
        row.tags.map((item, index) => {
          if (index > 1) return ""
          if (index > 0) return h(resumeTagPopup, {
            props:{
              tags:row.tags
            }
          }, [h("el-button", {
            props:{
              type:"text",
              size:"mini"
            },
            style:{
              padding:0,
              marginLeft:"6px",
              marginTop:"2px"
            }
          }, "更多")]) 
          const types = ["primary", "success", "warning", "danger"]
          return h("o-tag", {
            class:"ellipsis-1",
            props:{
              size:"mini",
              // type:types["danger"]
              type:types[Math.ceil(types.length * Math.random())]
            },
            style:{
              maxWidth:"70px",
            }
          }, item)
        })
        )
      }
      // item.formatter = (row) => {
      //   if (row.tags === null) return "-"
      //   return (row.tags || []).join(",")
      // }
    }

    item.minWidth = item.minWidth || 100
  }

  tableHeader.unshift({
    type:"INDEX",
    prop:"index",
    label:"序号",
    fixed:true
  })

  return tableHeader
}

// 面试评价标签 弹框 VNode
export function tableListCandidateInterviewPopup(item) {
  if (item.prop === "businessStatus") {

    const interviewStatus = this.stageType === 3
    
    item.render = (h, row) => {

      const showLabelName = row.status !== 4

      const candidateInterviewPopupVNode = h(candidateInterviewPopup, {
        props:{
          height:"260px",
          placement:"bottom",
        },
      }, [
        h("span", {
          style:{
            color:"var(--o-primary-color)"
          },
          class:"zp-ml-8 zp-cursor-pointer",
          on:{
            async click() {
              const candidateInterviewPopupInstance = candidateInterviewPopupVNode.componentInstance
              candidateInterviewPopupInstance.id = row.resumeId
              candidateInterviewPopupInstance.init()
            }
          }
        }, interviewStatus && showLabelName ? "(面试评价)" : "")
      ])

      return h("div", {
        style:{
          display:"flex"
        }
      }, [
        h("span", {
          style:{
            width:"6px",
            height:"6px",
            backgroundColor:(row.status === 4 || row.status === 5) ? "var(--o-primary-color)" : "#ccc",
            borderRadius:"50%",
            marginRight:"8px",
            top:"3px",
            position:"relative",
            flexShrink:0
          }
        }),
        h("span", row.businessStatus),
        candidateInterviewPopupVNode
      ])
    }

    item.minWidth = interviewStatus ? 180 : 110
  }
}

// 表格重复标签 VNode
export function tableListNameRepeatTagPopup (item) {
  if (item.prop !== "name") return 
  item.fixed = true
  item.showOverflowTooltip = false

  item.render = (h, row) => {

    // 已读未读
    let readTagVNode = h("span", {
      style:{
        backgroundColor:"red",
        flexShrink:"0",
        width:"4px",
        height:"4px",
        borderRadius:"100%",
        display:"inline-block",
        position: "relative",
        top: "-3px",
        marginRight: "6px",
      }
    })

    if (row.read || !("read" in row)) readTagVNode = ""

    const repeatResumePopupInstance =  h(repeatResumePopup, {
      props:{
        height:"260px",
        placement:"bottom",
        disabledClick:true
      }
    }, [
      h("div",  {
        style:{
          width:"24px",
          height:"20px",
          textAlign:"center",
          lineHeight:"20px",
          backgroundColor:"#FFF3F3",
          color:"#F63939",
          marginLeft:"4px",
          borderRadius:"4px"
        },
        on:{
          async click() {
            const repeatResumeReference = repeatResumePopupInstance.componentInstance
            repeatResumeReference.id = row.resumeId
            repeatResumeReference.init()
          }
        }
      }, "重")
    ])

    return h("div", {
      style:{
        display:"flex",
        alignItems:"center",
        cursor:"pointer"
      }
    }, [
      readTagVNode,
      h("app-omit-words-tooltip", {
        style:{
          maxWidth:"100px",
          color:"#5374f6",
          lineHeight:"20px"
        },
        props:{
          tag:"div",
          content:row.name
        },
        class:["ellipsis-1"],
        on:{
          click:() => {
            this.$routerPush({
              name:"recruitmentDetail",
              params:{
                resumeId:row.resumeId,
              }
            })
          }
        }
      }, row.name),
      row.repeat ? repeatResumePopupInstance : ""
    ])
  }
}